
# Slot: return_weight


Weight on the probability of returning to the same node the walk just came from Having this higher tends the walks to be more like a Breadth-First Search. Having this very high  (> 2) makes search very local. Equal to the inverse of p in the Node2Vec paper.

URI: [https://w3id.org/neat/nodeEmbeddingsParams__return_weight](https://w3id.org/neat/nodeEmbeddingsParams__return_weight)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Float](types/Float.md)

## Parents


## Children


## Used by

 * [NodeEmbeddingsParams](NodeEmbeddingsParams.md)
